/// @cond EO_CXX_EO_IMPL

inline void evas_3d_material::color_set(Evas_3D_Material_Attrib attrib_, Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_material_color_set(attrib_, r_, g_, b_, a_));
}

inline void evas_3d_material::color_get(Evas_3D_Material_Attrib attrib_, Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_material_color_get(attrib_, r_, g_, b_, a_));
}

inline bool evas_3d_material::enable_get(Evas_3D_Material_Attrib attrib_) const
{
   Eina_Bool _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_material_enable_get(attrib_));
   return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
}

inline void evas_3d_material::enable_set(Evas_3D_Material_Attrib attrib_, bool enable_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_material_enable_set(attrib_, ::efl::eolian::to_c(enable_)));
}

inline Evas_Real evas_3d_material::shininess_get() const
{
   Evas_Real _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_material_shininess_get());
   return _tmp_ret;
}

inline void evas_3d_material::shininess_set(Evas_Real shininess_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_material_shininess_set(shininess_));
}

inline Evas_3D_Texture * evas_3d_material::texture_get(Evas_3D_Material_Attrib attrib_) const
{
   Evas_3D_Texture * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_material_texture_get(attrib_));
   return _tmp_ret;
}

inline void evas_3d_material::texture_set(Evas_3D_Material_Attrib attrib_, Evas_3D_Texture * texture_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_material_texture_set(attrib_, texture_));
}

inline void eo_cxx::evas_3d_material::color_set(Evas_3D_Material_Attrib attrib_, Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_material_color_set(attrib_, r_, g_, b_, a_));
}

inline void eo_cxx::evas_3d_material::color_get(Evas_3D_Material_Attrib attrib_, Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_material_color_get(attrib_, r_, g_, b_, a_));
}

inline bool eo_cxx::evas_3d_material::enable_get(Evas_3D_Material_Attrib attrib_) const
{
   Eina_Bool _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_material_enable_get(attrib_));
   return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
}

inline void eo_cxx::evas_3d_material::enable_set(Evas_3D_Material_Attrib attrib_, bool enable_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_material_enable_set(attrib_, ::efl::eolian::to_c(enable_)));
}

inline Evas_Real eo_cxx::evas_3d_material::shininess_get() const
{
   Evas_Real _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_material_shininess_get());
   return _tmp_ret;
}

inline void eo_cxx::evas_3d_material::shininess_set(Evas_Real shininess_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_material_shininess_set(shininess_));
}

inline Evas_3D_Texture * eo_cxx::evas_3d_material::texture_get(Evas_3D_Material_Attrib attrib_) const
{
   Evas_3D_Texture * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_material_texture_get(attrib_));
   return _tmp_ret;
}

inline void eo_cxx::evas_3d_material::texture_set(Evas_3D_Material_Attrib attrib_, Evas_3D_Texture * texture_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_material_texture_set(attrib_, texture_));
}

inline ::eo_cxx::evas_3d_material::operator ::evas_3d_material() const
{
   return *static_cast<::evas_3d_material const*>(static_cast<void const*>(this));
}

inline ::eo_cxx::evas_3d_material::operator ::evas_3d_material&()
{
   return *static_cast<::evas_3d_material*>(static_cast<void*>(this));
}

inline ::eo_cxx::evas_3d_material::operator ::evas_3d_material const&() const
{
   return *static_cast<::evas_3d_material const*>(static_cast<void const*>(this));
}

template <typename T>
void _evas_3d_material_color_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_3D_Material_Attrib attrib_, Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_)
{
   try
      {
         static_cast<T*>(self->this_)->color_set(attrib_, r_, g_, b_, a_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void _evas_3d_material_color_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_3D_Material_Attrib attrib_, Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_)
{
   try
      {
         static_cast<T*>(self->this_)->color_get(attrib_, r_, g_, b_, a_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
bool _evas_3d_material_enable_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_3D_Material_Attrib attrib_)
{
   bool _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->enable_get(attrib_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void _evas_3d_material_enable_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_3D_Material_Attrib attrib_, Eina_Bool enable_)
{
   try
      {
         static_cast<T*>(self->this_)->enable_set(attrib_, ::efl::eolian::to_cxx<bool>(enable_, std::tuple<std::false_type>()));
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
Evas_Real _evas_3d_material_shininess_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   Evas_Real _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->shininess_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void _evas_3d_material_shininess_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Real shininess_)
{
   try
      {
         static_cast<T*>(self->this_)->shininess_set(shininess_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
Evas_3D_Texture * _evas_3d_material_texture_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_3D_Material_Attrib attrib_)
{
   Evas_3D_Texture * _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->texture_get(attrib_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void _evas_3d_material_texture_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_3D_Material_Attrib attrib_, Evas_3D_Texture * texture_)
{
   try
      {
         static_cast<T*>(self->this_)->texture_set(attrib_, texture_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::evas_3d_material >
{
   template <typename T>
   struct type
         : virtual operations< ::evas_3d_object >::template type<T>
         , virtual operations< ::evas::common_interface >::template type<T>
   {
      virtual void color_set(Evas_3D_Material_Attrib attrib_, Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_material_color_set(attrib_, r_, g_, b_, a_));
      }

      virtual void color_get(Evas_3D_Material_Attrib attrib_, Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_material_color_get(attrib_, r_, g_, b_, a_));
      }

      virtual bool enable_get(Evas_3D_Material_Attrib attrib_)
      {
         Eina_Bool _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_3d_material_enable_get(attrib_));
            return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void enable_set(Evas_3D_Material_Attrib attrib_, bool enable_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_material_enable_set(attrib_, ::efl::eolian::to_c(enable_)));
      }

      virtual Evas_Real shininess_get()
      {
         Evas_Real _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_3d_material_shininess_get());
            return _tmp_ret;
      }

      virtual void shininess_set(Evas_Real shininess_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_material_shininess_set(shininess_));
      }

      virtual Evas_3D_Texture * texture_get(Evas_3D_Material_Attrib attrib_)
      {
         Evas_3D_Texture * _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_3d_material_texture_get(attrib_));
            return _tmp_ret;
      }

      virtual void texture_set(Evas_3D_Material_Attrib attrib_, Evas_3D_Texture * texture_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_material_texture_set(attrib_, texture_));
      }

   };
};


#ifdef EVAS_3D_MATERIAL_PROTECTED
template<>
struct operation_description_class_size< ::evas_3d_material >
{
   static constexpr int value = 8 + operation_description_class_size<::evas_3d_object >::value + operation_description_class_size<::evas::common_interface >::value;
};

#else
template<>
struct operation_description_class_size< ::evas_3d_material >
{
   static constexpr int value = 8 + operation_description_class_size<::evas_3d_object >::value + operation_description_class_size<::evas::common_interface >::value;
};

#endif

template <typename T>
int initialize_operation_description(::efl::eo::detail::tag<::evas_3d_material>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_evas_3d_material_color_set_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::evas_3d_material_color_set);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_evas_3d_material_color_get_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::evas_3d_material_color_get);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_evas_3d_material_enable_get_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::evas_3d_material_enable_get);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_evas_3d_material_enable_set_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::evas_3d_material_enable_set);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_evas_3d_material_shininess_get_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::evas_3d_material_shininess_get);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_evas_3d_material_shininess_set_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::evas_3d_material_shininess_set);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_evas_3d_material_texture_get_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::evas_3d_material_texture_get);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_evas_3d_material_texture_set_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::evas_3d_material_texture_set);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   initialize_operation_description<T>(::efl::eo::detail::tag<::evas_3d_object>(), &ops[operation_description_class_size< ::evas_3d_material >::value]);
   initialize_operation_description<T>(::efl::eo::detail::tag<::evas::common_interface>(), &ops[operation_description_class_size< ::evas_3d_material >::value + operation_description_class_size<::evas_3d_object>::value]);
   return 0;
}
inline Eo_Class const* get_eo_class(tag<::evas_3d_material>)
{
   return (EVAS_3D_MATERIAL_CLASS);
}

} } }

/// @endcond

